@@ -18,7 +18,8 @@ def run_relevant_plugins(registry_hive, as_json=False, plugins=None):
             continue
 
         if plugin.can_run():
-            plugin_results[plugin.NAME] = plugin.run()
+            plugin.run()
+            plugin_results[plugin.NAME] = plugin.entries
     return plugin_results
 
 
